import React, { useState } from 'react';
import styled from '@emotion/styled';
import Avatar from "@mui/material/Avatar";

const PhotoStyled = styled.div`
  position: relative;
  display: inline-block;
  cursor: pointer;
`;

const AvatarStyled = styled(Avatar)`
  width: 200px;
  height: 200px;
`;

const InputStyled = styled.input`
  display: none;
`;

function Photo({ defaultPhoto, onPhotoChange }) {
  const [photo, setPhoto] = useState(defaultPhoto);

  const handleFileChange = (event) => {
    const file = event.target.files[0];
    if (file) {
      const reader = new FileReader();

      reader.onload = (e) => {
        const newPhoto = e.target.result;
        setPhoto(newPhoto);
        if (onPhotoChange) onPhotoChange(newPhoto); 
      };

      reader.readAsDataURL(file);
    }
  };

  const handleAvatarClick = () => {
    const fileInput = document.getElementById('fileInput') as HTMLInputElement;
    fileInput.click();
  }

  
  return (
    <PhotoStyled>
      <AvatarStyled
        src={photo}
        alt="Выберите фотографию"
        onClick={handleAvatarClick}
       />
      <InputStyled
        id="fileInput"
        type="file"
        accept="image/*"
        onChange={handleFileChange}
      />
    </PhotoStyled>
  );
  
}

export default Photo;
